@@ -48,10 +48,10 @@ def check_columns(filename, columns):
     
     # check columns
     for c in columns:
-        assert c in df.columns, ('%s not included' % c)
+        assert c in df.columns, ('"%s" not included' % c)
     
     for c in df.columns:
-        assert c in columns, ("%s included when it shouldn't be" % c)
+        assert c in columns, ("'%s' included when it shouldn't be" % c)
     
     # check column length
     assert_equal(len(df.columns), len(columns))
@@ -74,7 +74,7 @@ def test_columns_no_fit(b=None):
             continue
             
         # no fit values
-        if c in ['Chi-Squared',]:
+        if c in ['Chi-Squared', 'T1', 'Error T1']:
             continue
         
         # copy values
@@ -146,6 +146,9 @@ def test_columns_with_fit(b=None):
         columns.append('fixed '+name)
         columns.append('shared '+name)
     
+    del columns[columns.index('all the above')]
+    del columns[columns.index('Error all the above')]
+    
     check_columns(filename, columns)
     
     # clean
